@@ -17,11 +17,11 @@ FCGI::Buffer - Verify and Optimise FCGI Output
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =cut
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 =head1 SYNOPSIS
 
@@ -804,9 +804,10 @@ Synonym for init, kept for historical reasons.
 =cut
 
 sub set_options {
-	my %params = @_;
+	my $self = shift;
+	my %params = (ref($_[0]) eq 'HASH') ? %{$_[0]} : @_;
 
-	init(%params);
+	$self->init(\%params);
 }
 
 =head2 can_cache
@@ -964,14 +965,16 @@ sub _should_gzip {
 		my $accept = lc($ENV{'HTTP_ACCEPT_ENCODING'} ? $ENV{'HTTP_ACCEPT_ENCODING'} : $ENV{'HTTP_TE'});
 		foreach my $encoding ('x-gzip', 'gzip') {
 			$_ = $accept;
-			my @content_type = @{$self->{content_type}};
-			if($content_type[0]) {
-				if (m/$encoding/i && (lc($content_type[0]) eq 'text')) {
-					return $encoding;
-				}
-			} else {
-				if (m/$encoding/i) {
-					return $encoding;
+			if(defined($self->{content_type})) {
+				my @content_type = @{$self->{content_type}};
+				if($content_type[0]) {
+					if (m/$encoding/i && (lc($content_type[0]) eq 'text')) {
+						return $encoding;
+					}
+				} else {
+					if (m/$encoding/i) {
+						return $encoding;
+					}
 				}
 			}
 		}
@@ -1014,7 +1017,7 @@ The letter of the spec says that's wrong, so I'm noting it here, but
 in practice you should not see this happen or have any difficulties
 because of it.
 
-FCGI::Buffer is not compatible with FastCGI.
+FCGI::Buffer has not been tested against FastCGI.
 
 I advise adding FCGI::Buffer as the last use statement so that it is
 cleared up first.  In particular it should be loaded after
@@ -1022,9 +1025,7 @@ L<Log::Log4Perl>, if you're using that, so that any messages it
 produces are printed after the HTTP headers have been sent by
 FCGI::Buffer;
 
-FCGI::Buffer is not compatible with FCGI.
-
-Please report any bugs or feature requests to C<bug-cgi-buffer at rt.cpan.org>,
+Please report any bugs or feature requests to C<bug-fcgi-buffer at rt.cpan.org>,
 or through the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=FCGI-Buffer>.
 I will be notified, and then you'll automatically be notified of progress on
 your bug as I make changes.
